@@ -19,8 +19,8 @@ gl_webhooks_service_status 1
 
     # Metrics for api webhooks/gitlab/jobs.py
     data = jobs.action_jobs_file(app, None)
-    pending = len([True for v in data.values() if v == "pending"])
-    running = len([True for v in data.values() if v == "running"])
+    pending = len([True for v in data.values() if v["status"] == "pending"])
+    running = len([True for v in data.values() if v["status"] == "running"])
     retval += """
 # HELP gl_webhooks_jobs_count Count of jobs
 # TYPE gl_webhooks_jobs_count gauge
